
![publish-pypi](https://github.com/matthewashley1/Fetch_BehrTech/workflows/publish-pypi/badge.svg)

# py_behrtech

A python wrapper for BehrTech's Mythings Central REST API. Currently supporting version 3.0.0

## Status

This package is a work in progress. Currently working to get all API endpoints implemented with checks on each returned status code.

### Task List

- [ ] azurefunctionDelete
- [ ] azurefunctionFunctionIDDelete
- [ ] azurefunctionFunctionIDGet
- [ ] azurefunctionGet
- [ ] azurefunctionPost
- [ ] azurefunctionDelete
- [ ] azuremappingGet
- [ ] azuremappingMappingIDDelete
- [ ] azuremappingMappingIDGet
- [ ] azuremappingPost

## License

Fetch_BehrTech is released under the [MIT](https://opensource.org/licenses/MIT) license
